Class: Aws::BackupSearch::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BackupSearch::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-backupsearch/client.rb,
sig/client.rbs
Overview
An API client for BackupSearch. To construct a client, you need to configure a :region and :credentials.
client = Aws::BackupSearch::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetSearchJobResponseSuccess, _GetSearchResultExportJobResponseSuccess, _ListSearchJobBackupsResponseSuccess, _ListSearchJobResultsResponseSuccess, _ListSearchJobsResponseSuccess, _ListSearchResultExportJobsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartSearchJobResponseSuccess, _StartSearchResultExportJobResponseSuccess, _StopSearchJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_search_job(params = {}) ⇒ Types::GetSearchJobOutput
This operation retrieves metadata of a search job, including its progress.
-
#get_search_result_export_job(params = {}) ⇒ Types::GetSearchResultExportJobOutput
This operation retrieves the metadata of an export job.
-
#list_search_job_backups(params = {}) ⇒ Types::ListSearchJobBackupsOutput
This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
-
#list_search_job_results(params = {}) ⇒ Types::ListSearchJobResultsOutput
This operation returns a list of a specified search job.
-
#list_search_jobs(params = {}) ⇒ Types::ListSearchJobsOutput
This operation returns a list of search jobs belonging to an account.
-
#list_search_result_export_jobs(params = {}) ⇒ Types::ListSearchResultExportJobsOutput
This operation exports search results of a search job to a specified destination S3 bucket.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation returns the tags for a resource type.
-
#start_search_job(params = {}) ⇒ Types::StartSearchJobOutput
This operation creates a search job which returns recovery points filtered by SearchScope and items filtered by ItemFilters.
-
#start_search_result_export_job(params = {}) ⇒ Types::StartSearchResultExportJobOutput
This operations starts a job to export the results of search job to a designated S3 bucket.
-
#stop_search_job(params = {}) ⇒ Struct
This operations ends a search job.
-
#tag_resource(params = {}) ⇒ Struct
This operation puts tags on the resource you indicate.
-
#untag_resource(params = {}) ⇒ Struct
This operation removes tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1205 1206 1207 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1205 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1208 1209 1210 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1208 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1178 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BackupSearch') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-backupsearch' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#get_search_job(params = {}) ⇒ Types::GetSearchJobOutput
This operation retrieves metadata of a search job, including its progress.
97 |
# File 'sig/client.rbs', line 97
def get_search_job: (
|
#get_search_result_export_job(params = {}) ⇒ Types::GetSearchResultExportJobOutput
This operation retrieves the metadata of an export job.
An export job is an operation that transmits the results of a search job to a specified S3 bucket in a .csv file.
An export job allows you to retain results of a search beyond the search job's scheduled retention of 7 days.
114 |
# File 'sig/client.rbs', line 114
def get_search_result_export_job: (
|
#list_search_job_backups(params = {}) ⇒ Types::ListSearchJobBackupsOutput
This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
If a search does not display an expected backup in the results, you
can call this operation to display each backup included in the search.
Any backups that were not included because they have a FAILED status
from a permissions issue will be displayed, along with a status
message.
Only recovery points with a backup index that has a status of ACTIVE
will be included in search results. If the index has any other status,
its status will be displayed along with a status message.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
125 |
# File 'sig/client.rbs', line 125
def list_search_job_backups: (
|
#list_search_job_results(params = {}) ⇒ Types::ListSearchJobResultsOutput
This operation returns a list of a specified search job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
138 |
# File 'sig/client.rbs', line 138
def list_search_job_results: (
|
#list_search_jobs(params = {}) ⇒ Types::ListSearchJobsOutput
This operation returns a list of search jobs belonging to an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
151 |
# File 'sig/client.rbs', line 151
def list_search_jobs: (
|
#list_search_result_export_jobs(params = {}) ⇒ Types::ListSearchResultExportJobsOutput
This operation exports search results of a search job to a specified destination S3 bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
164 |
# File 'sig/client.rbs', line 164
def list_search_result_export_jobs: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation returns the tags for a resource type.
177 |
# File 'sig/client.rbs', line 177
def list_tags_for_resource: (
|
#start_search_job(params = {}) ⇒ Types::StartSearchJobOutput
This operation creates a search job which returns recovery points filtered by SearchScope and items filtered by ItemFilters.
You can optionally include ClientToken, EncryptionKeyArn, Name, and/or Tags.
189 |
# File 'sig/client.rbs', line 189
def start_search_job: (
|
#start_search_result_export_job(params = {}) ⇒ Types::StartSearchResultExportJobOutput
This operations starts a job to export the results of search job to a designated S3 bucket.
277 |
# File 'sig/client.rbs', line 277
def start_search_result_export_job: (
|
#stop_search_job(params = {}) ⇒ Struct
This operations ends a search job.
Only a search job with a status of RUNNING can be stopped.
295 |
# File 'sig/client.rbs', line 295
def stop_search_job: (
|
#tag_resource(params = {}) ⇒ Struct
This operation puts tags on the resource you indicate.
304 |
# File 'sig/client.rbs', line 304
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
This operation removes tags from the specified resource.
314 |
# File 'sig/client.rbs', line 314
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1198 1199 1200 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1198 def waiter_names [] end |