Class: Aws::BackupSearch::Types::TimeCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::BackupSearch::Types::TimeCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backupsearch/types.rb
Overview
A time condition denotes a creation time, last modification time, or other time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operator ⇒ String
A string that defines what values will be returned.
-
#value ⇒ Time
This is the timestamp value of the time condition.
Instance Attribute Details
#operator ⇒ String
A string that defines what values will be returned.
If this is included, avoid combinations of operators that will return all possible values. For example, including both ‘EQUALS_TO` and `NOT_EQUALS_TO` with a value of `4` will return all values.
1421 1422 1423 1424 1425 1426 |
# File 'lib/aws-sdk-backupsearch/types.rb', line 1421 class TimeCondition < Struct.new( :value, :operator) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Time
This is the timestamp value of the time condition.
1421 1422 1423 1424 1425 1426 |
# File 'lib/aws-sdk-backupsearch/types.rb', line 1421 class TimeCondition < Struct.new( :value, :operator) SENSITIVE = [] include Aws::Structure end |