Class: Aws::BackupSearch::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BackupSearch::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-backupsearch/client.rb
Overview
An API client for BackupSearch. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BackupSearch::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_search_job(params = {}) ⇒ Types::GetSearchJobOutput
This operation retrieves metadata of a search job, including its progress.
-
#get_search_result_export_job(params = {}) ⇒ Types::GetSearchResultExportJobOutput
This operation retrieves the metadata of an export job.
-
#list_search_job_backups(params = {}) ⇒ Types::ListSearchJobBackupsOutput
This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
-
#list_search_job_results(params = {}) ⇒ Types::ListSearchJobResultsOutput
This operation returns a list of a specified search job.
-
#list_search_jobs(params = {}) ⇒ Types::ListSearchJobsOutput
This operation returns a list of search jobs belonging to an account.
-
#list_search_result_export_jobs(params = {}) ⇒ Types::ListSearchResultExportJobsOutput
This operation exports search results of a search job to a specified destination S3 bucket.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation returns the tags for a resource type.
-
#start_search_job(params = {}) ⇒ Types::StartSearchJobOutput
This operation creates a search job which returns recovery points filtered by SearchScope and items filtered by ItemFilters.
-
#start_search_result_export_job(params = {}) ⇒ Types::StartSearchResultExportJobOutput
This operations starts a job to export the results of search job to a designated S3 bucket.
-
#stop_search_job(params = {}) ⇒ Struct
This operations ends a search job.
-
#tag_resource(params = {}) ⇒ Struct
This operation puts tags on the resource you indicate.
-
#untag_resource(params = {}) ⇒ Struct
This operation removes tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1205 1206 1207 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1205 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1208 1209 1210 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1208 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1178 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BackupSearch') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-backupsearch' context[:gem_version] = '1.22.0' Seahorse::Client::Request.new(handlers, context) end |
#get_search_job(params = {}) ⇒ Types::GetSearchJobOutput
This operation retrieves metadata of a search job, including its progress.
563 564 565 566 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 563 def get_search_job(params = {}, = {}) req = build_request(:get_search_job, params) req.send_request() end |
#get_search_result_export_job(params = {}) ⇒ Types::GetSearchResultExportJobOutput
This operation retrieves the metadata of an export job.
An export job is an operation that transmits the results of a search job to a specified S3 bucket in a .csv file.
An export job allows you to retain results of a search beyond the search job’s scheduled retention of 7 days.
614 615 616 617 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 614 def get_search_result_export_job(params = {}, = {}) req = build_request(:get_search_result_export_job, params) req.send_request() end |
#list_search_job_backups(params = {}) ⇒ Types::ListSearchJobBackupsOutput
This operation returns a list of all backups (recovery points) in a paginated format that were included in the search job.
If a search does not display an expected backup in the results, you can call this operation to display each backup included in the search. Any backups that were not included because they have a ‘FAILED` status from a permissions issue will be displayed, along with a status message.
Only recovery points with a backup index that has a status of ‘ACTIVE` will be included in search results. If the index has any other status, its status will be displayed along with a status message.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
677 678 679 680 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 677 def list_search_job_backups(params = {}, = {}) req = build_request(:list_search_job_backups, params) req.send_request() end |
#list_search_job_results(params = {}) ⇒ Types::ListSearchJobResultsOutput
This operation returns a list of a specified search job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
737 738 739 740 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 737 def list_search_job_results(params = {}, = {}) req = build_request(:list_search_job_results, params) req.send_request() end |
#list_search_jobs(params = {}) ⇒ Types::ListSearchJobsOutput
This operation returns a list of search jobs belonging to an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
790 791 792 793 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 790 def list_search_jobs(params = {}, = {}) req = build_request(:list_search_jobs, params) req.send_request() end |
#list_search_result_export_jobs(params = {}) ⇒ Types::ListSearchResultExportJobsOutput
This operation exports search results of a search job to a specified destination S3 bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
848 849 850 851 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 848 def list_search_result_export_jobs(params = {}, = {}) req = build_request(:list_search_result_export_jobs, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation returns the tags for a resource type.
878 879 880 881 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 878 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_search_job(params = {}) ⇒ Types::StartSearchJobOutput
This operation creates a search job which returns recovery points filtered by SearchScope and items filtered by ItemFilters.
You can optionally include ClientToken, EncryptionKeyArn, Name, and/or Tags.
1020 1021 1022 1023 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1020 def start_search_job(params = {}, = {}) req = build_request(:start_search_job, params) req.send_request() end |
#start_search_result_export_job(params = {}) ⇒ Types::StartSearchResultExportJobOutput
This operations starts a job to export the results of search job to a designated S3 bucket.
1084 1085 1086 1087 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1084 def start_search_result_export_job(params = {}, = {}) req = build_request(:start_search_result_export_job, params) req.send_request() end |
#stop_search_job(params = {}) ⇒ Struct
This operations ends a search job.
Only a search job with a status of ‘RUNNING` can be stopped.
1108 1109 1110 1111 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1108 def stop_search_job(params = {}, = {}) req = build_request(:stop_search_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
This operation puts tags on the resource you indicate.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1141 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
This operation removes tags from the specified resource.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1169 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1198 1199 1200 |
# File 'lib/aws-sdk-backupsearch/client.rb', line 1198 def waiter_names [] end |